@@ -83,7 +83,6 @@ export const loadLabContents = async (widget: NotebookPanel, axiosHandlers: Axio
       const lab_model = (await getLabModel(
         axiosHandlers
       )) as unknown as nbformat.INotebookContent;
-      // console.log('heres the model: ', lab_model);
       model.fromJSON(lab_model);
     } catch {
       throw 'Error getting lab model';
@@ -108,7 +107,7 @@ export const parseJwt = (token: string) => {
 }
 
 export const getLabFilePath = (jwtparsed: any): string => {
-  let labFilename = jwtparsed.filepath ?? Globals.DEFAULT_LAB_NAME;
+  let labFilename = jwtparsed.lab_filepath ?? Globals.DEFAULT_LAB_NAME;
   // Replace labs/ prefix with empty string
   // TODO: We need a more robust way to do this and not rely on the assumption that the lab is in the labs folder
   // TODO: This is required as the createNew method will not automatically create the parent directories
